Deep Neural Networks (dnn module) {#tutorial_table_of_content_dnn}
=====================================

-   @subpage tutorial_dnn_googlenet

    *Compatibility:* \> OpenCV 3.3

    *Author:* Vitaliy Lyudvichenko

    In this tutorial you will learn how to use opencv_dnn module for image classification by using GoogLeNet trained network from Caffe model zoo.

-   @subpage tutorial_dnn_halide

    *Compatibility:* \> OpenCV 3.3

    *Author:* Dmitry Kurtaev

    This tutorial guidelines how to run your models in OpenCV deep learning module using Halide language backend.

-   @subpage tutorial_dnn_halide_scheduling

    *Compatibility:* \> OpenCV 3.3

    *Author:* Dmitry Kurtaev

    In this tutorial we describe the ways to schedule your networks using Halide backend in OpenCV deep learning module.

-   @subpage tutorial_dnn_android

    *Compatibility:* \> OpenCV 3.3

    *Author:* Dmitry Kurtaev

    This tutorial will show you how to run deep learning model using OpenCV on Android device.

-   @subpage tutorial_dnn_yolo

    *Compatibility:* \> OpenCV 3.3.1

    *Author:* Alessandro de Oliveira Faria

    In this tutorial you will learn how to use opencv_dnn module using yolo_object_detection with device capture, video file or image.

-   @subpage tutorial_dnn_javascript

    *Compatibility:* \> OpenCV 3.3.1

    *Author:* Dmitry Kurtaev

    In this tutorial we'll run deep learning models in browser using OpenCV.js.
